@@ -14,7 +14,7 @@
     Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "signatureconfigurator.h"
@@ -109,7 +109,7 @@ void SignatureConfigurator::Private::init()
     QVBoxLayout *vlay = new QVBoxLayout(q);
     vlay->setObjectName(QStringLiteral("main layout"));
 
-    // "enable signatue" checkbox:
+    // "enable signature" checkbox:
     mEnableCheck = new QCheckBox(i18n("&Enable signature"), q);
     mEnableCheck->setWhatsThis(
         i18n("Check this box if you want KMail to append a signature to mails "
@@ -156,7 +156,7 @@ void SignatureConfigurator::Private::init()
     QWidget *page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);
     QVBoxLayout *page_vlay = new QVBoxLayout(page);
-    page_vlay->setMargin(0);
+    page_vlay->setContentsMargins(0, 0, 0, 0);
 
 #ifndef QT_NO_TOOLBAR
     mEditToolBar = new KToolBar(q);
@@ -225,7 +225,7 @@ void SignatureConfigurator::Private::init()
     page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);   // force sequential numbers (play safe)
     page_vlay = new QVBoxLayout(page);
-    page_vlay->setMargin(0);
+    page_vlay->setContentsMargins(0, 0, 0, 0);
     hlay = new QHBoxLayout(); // inherits spacing
     page_vlay->addLayout(hlay);
     mFileRequester = new KUrlRequester(page);
@@ -254,7 +254,7 @@ void SignatureConfigurator::Private::init()
     page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);
     page_vlay = new QVBoxLayout(page);
-    page_vlay->setMargin(0);
+    page_vlay->setContentsMargins(0, 0, 0, 0);
     hlay = new QHBoxLayout(); // inherits spacing
     page_vlay->addLayout(hlay);
     mCommandEdit = new KLineEdit(page);
@@ -266,7 +266,8 @@ void SignatureConfigurator::Private::init()
              "depending on whether or not the command is in your Path. For every "
              "new mail, KMail will execute the command and use what it outputs (to "
              "standard output) as a signature. Usual commands for use with this "
-             "mechanism are \"fortune\" or \"ksig -random\"."));
+             "mechanism are \"fortune\" or \"ksig -random\". "
+             "(Be careful, script needs a shebang line)."));
     label = new QLabel(i18n("S&pecify command:"), page);
     label->setBuddy(mCommandEdit);
     hlay->addWidget(label);
